@@ -1,4 +1,7 @@
 import logging
+import os
+
+from django.conf import settings
 
 from .rg_redis.redis_cache import RedisCache
 
@@ -19,6 +22,9 @@ class RGLoggerCache:
 
     @classmethod
     def is_debug_enabled(cls) -> bool:
+        if settings.DEBUG:
+            return True
+
         redis_value = cls._get_cache().get_string_value(cls._get_redis_key())
 
         return True if redis_value == "true" else False
@@ -33,7 +39,10 @@ logger = logging.getLogger('debug')
 
 def info(msg):
     if RGLoggerCache.is_debug_enabled():
-        logger.info(msg)
+        try:
+            logger.info("PID: %s, %s", str(os.getpid()), msg)
+        except Exception as e:
+            logger.info(msg);
 
 
 def info_important(msg):
